==> opennms-dao-21.0.0-20170920.111958-93-sources.jar: org/opennms/netmgt/dao/support/LazyResourceAttributeLoader.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.support;

import java.util.Set;

import org.opennms.core.utils.LazySet;
import org.opennms.netmgt.dao.api.ResourceStorageDao;
import org.opennms.netmgt.model.OnmsAttribute;
import org.opennms.netmgt.model.ResourcePath;

public class LazyResourceAttributeLoader implements LazySet.Loader<OnmsAttribute> {

    private final ResourceStorageDao m_resourceStorageDao;
    
    private final ResourcePath m_path;

    public LazyResourceAttributeLoader(ResourceStorageDao resourceStorageDao, ResourcePath path) {
        m_resourceStorageDao = resourceStorageDao;
        m_path = path;
    }

    @Override
    public Set<OnmsAttribute> load() {
        return m_resourceStorageDao.getAttributes(m_path);
    }
}

==> opennms-dao-25.0.0-20200607.062043-217-sources.jar: org/opennms/netmgt/dao/support/LazyResourceAttributeLoader.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2002-2014 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2014 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.dao.support;

import java.util.Set;

import org.opennms.core.collections.LazySet;
import org.opennms.netmgt.dao.api.ResourceStorageDao;
import org.opennms.netmgt.model.OnmsAttribute;
import org.opennms.netmgt.model.ResourcePath;

public class LazyResourceAttributeLoader implements LazySet.Loader<OnmsAttribute> {

    private final ResourceStorageDao m_resourceStorageDao;
    
    private final ResourcePath m_path;

    public LazyResourceAttributeLoader(ResourceStorageDao resourceStorageDao, ResourcePath path) {
        m_resourceStorageDao = resourceStorageDao;
        m_path = path;
    }

    @Override
    public Set<OnmsAttribute> load() {
        return m_resourceStorageDao.getAttributes(m_path);
    }
}
